@@ -16,8 +16,7 @@
 
    You should have received a copy of the GNU Library General Public
    License along with the Gnome Library; see the file COPYING.LIB.  If not,
-   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   see <http://www.gnu.org/licenses/>.
 
    Authors: Alexander Larsson <alexl@redhat.com>
 */
@@ -43,5 +42,6 @@ GdkPixbuf * nautilus_ui_get_menu_icon              (const char        *icon_name
 char * nautilus_escape_action_name                 (const char        *action_name,
 						    const char        *prefix);
 void   nautilus_ui_frame_image                     (GdkPixbuf        **pixbuf);
+void   nautilus_ui_frame_video                     (GdkPixbuf        **pixbuf);
 
 #endif /* NAUTILUS_UI_UTILITIES_H */
