@@ -655,24 +655,20 @@ void
 nautilus_location_entry_set_secondary_action (NautilusLocationEntry *entry,
 					      NautilusLocationEntryAction secondary_action)
 {
-	gboolean rtl;
-
 	if (entry->details->secondary_action == secondary_action) {
 		return;
 	}
 
-	rtl = gtk_widget_get_direction (GTK_WIDGET (entry)) == GTK_TEXT_DIR_RTL;
-
 	switch (secondary_action) {
 	case NAUTILUS_LOCATION_ENTRY_ACTION_CLEAR:
 		gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry), 
 						   GTK_ENTRY_ICON_SECONDARY,
-						   rtl ? "edit-clear-rtl-symbolic" : "edit-clear-symbolic");
+						   "edit-clear-symbolic");
 		break;
 	case NAUTILUS_LOCATION_ENTRY_ACTION_GOTO:
 		gtk_entry_set_icon_from_icon_name (GTK_ENTRY (entry),
 						   GTK_ENTRY_ICON_SECONDARY,
-						   rtl ? "go-next-rtl-symbolic" : "go-next-symbolic");
+						   "go-next-symbolic");
 		break;
 	default:
 		g_assert_not_reached ();
