@@ -2029,21 +2029,13 @@ activate_activation_uris_ready_callback (GList *files_ignore,
 
 	/* Convert the files to the actual activation uri files */
 	for (l = parameters->locations; l != NULL; l = l->next) {
-		char *uri = NULL;
-
+		char *uri;
 		location = l->data;
 
 		/* We want the file for the activation URI since we care
 		 * about the attributes for that, not for the original file.
 		 */
-		if (nautilus_file_is_symbolic_link (location->file)) {
-			uri = nautilus_file_get_symbolic_link_target_uri (location->file);
-		}
-
-		if (uri == NULL) {
-			uri = nautilus_file_get_activation_uri (location->file);
-		}
-
+		uri = nautilus_file_get_activation_uri (location->file);
 		if (uri != NULL) {
 			launch_location_update_from_uri (location, uri);
 		}
